==> q3-ui-filemanager-3.13.0.tgz: package/lib/DirectorySort/DirectorySort.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _q3UiHelpers = require("q3-ui-helpers");

var _MenuItem = _interopRequireDefault(require("@material-ui/core/MenuItem"));

var _Check = _interopRequireDefault(require("@material-ui/icons/Check"));

var _enzymeUtils = require("q3-ui-test-utils/lib/enzymeUtils");

var _DirectorySort = _interopRequireWildcard(require("./DirectorySort"));

var _useDirectoryFolders = _interopRequireDefault(require("../useDirectoryFolders"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.mock('../useDirectoryFolders');

const getMenuItems = () => {
  let Menu;
  global.shallow( /*#__PURE__*/_react.default.createElement(_DirectorySort.default, null, (_, Component) => {
    Menu = Component;
    return null;
  }));
  return global.shallow( /*#__PURE__*/_react.default.createElement(Menu, null)).dive().find(_MenuItem.default);
};

describe('DirectorySort', () => {
  describe('getFromLocalStorage', () => {
    it('should query browser storage with appended key name', () => {
      const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue('name');
      expect((0, _DirectorySort.getFromLocalStorage)('test', 'fallback')).toMatch('name');
      expect(spy).toHaveBeenCalledWith('getItem', 'q3-filemanager-test');
    });
    it('should return default', () => {
      jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue(undefined);
      expect((0, _DirectorySort.getFromLocalStorage)('test', 'fallback')).toMatch('fallback');
    });
  });
  describe('castPropertyToLowerCase', () => {
    it('should return object property in lowercase', () => {
      expect((0, _DirectorySort.castPropertyToLowerCase)('test')({
        test: 'FOO'
      })).toEqual('foo');
    });
    it('should return object property as undefined', () => {
      expect((0, _DirectorySort.castPropertyToLowerCase)('test')({})).toEqual('undefined');
    });
  });
  it('should sort files/siblings by prop and direction', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [{
        name: 'archive'
      }, {
        name: 'greatest hits'
      }, {
        name: 'b-sides'
      }],
      siblings: [{
        name: 'Januaray'
      }, {
        name: 'November'
      }]
    });

    const el = jest.spyOn(_react.default, 'useState');
    el.mockReturnValue([{
      property: 'name',
      sort: 'desc'
    }]);
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectorySort.default, null, ({
      files,
      siblings
    }) => {
      expect(files).toEqual([{
        name: 'greatest hits'
      }, {
        name: 'b-sides'
      }, {
        name: 'archive'
      }]);
      expect(siblings).toEqual([{
        name: 'November'
      }, {
        name: 'Januaray'
      }]);
      return null;
    }));
    expect(el).toHaveBeenCalledWith({
      property: 'name',
      sort: 'asc'
    });
  });
  it('should mark menu items when active', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [],
      siblings: []
    });

    const items = getMenuItems(); // 3 props and 2 directions

    expect(items).toHaveLength(5);
    const updatedAt = items.first();
    const name = items.at(1); // confirms we're looking at the right ones

    expect(updatedAt.text()).toMatch('updatedAt');
    expect(name.text()).toMatch('name');
    (0, _enzymeUtils.doesNotExist)(updatedAt.find(_Check.default));
    (0, _enzymeUtils.exists)(name.find(_Check.default));
  });
  it('should update state partially on menu click', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [],
      siblings: []
    });

    const setState = jest.fn().mockImplementation(c => expect(c({
      property: 'size',
      sort: 'asc'
    })).toMatchObject({
      property: 'size',
      sort: 'desc'
    }));
    jest.spyOn(_react.default, 'useState').mockReturnValue([{}, setState]);
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue(undefined);
    getMenuItems().last().props().onClick();
    expect(setState).toHaveBeenCalled();
    expect(spy).toHaveBeenCalledWith('setItem', 'q3-filemanager-sort', 'desc');
  });
});

==> q3-ui-filemanager-4.5.13.tgz: package/lib/DirectorySort/DirectorySort.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));
var _q3UiHelpers = require("q3-ui-helpers");
var _MenuItem = _interopRequireDefault(require("@material-ui/core/MenuItem"));
var _Check = _interopRequireDefault(require("@material-ui/icons/Check"));
var _enzymeUtils = require("q3-ui-test-utils/lib/enzymeUtils");
var _DirectorySort = _interopRequireWildcard(require("./DirectorySort"));
var _useDirectoryFolders = _interopRequireDefault(require("../useDirectoryFolders"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('../useDirectoryFolders');
const getMenuItems = () => {
  let Menu;
  global.shallow( /*#__PURE__*/_react.default.createElement(_DirectorySort.default, null, (_, Component) => {
    Menu = Component;
    return null;
  }));
  return global.shallow( /*#__PURE__*/_react.default.createElement(Menu, null)).dive().find(_MenuItem.default);
};
describe('DirectorySort', () => {
  describe('getFromLocalStorage', () => {
    it('should query browser storage with appended key name', () => {
      const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue('name');
      expect((0, _DirectorySort.getFromLocalStorage)('test', 'fallback')).toMatch('name');
      expect(spy).toHaveBeenCalledWith('getItem', 'q3-filemanager-test');
    });
    it('should return default', () => {
      jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue(undefined);
      expect((0, _DirectorySort.getFromLocalStorage)('test', 'fallback')).toMatch('fallback');
    });
  });
  describe('castPropertyToLowerCase', () => {
    it('should return object property in lowercase', () => {
      expect((0, _DirectorySort.castPropertyToLowerCase)('test')({
        test: 'FOO'
      })).toEqual('foo');
    });
    it('should return object property as undefined', () => {
      expect((0, _DirectorySort.castPropertyToLowerCase)('test')({})).toEqual('undefined');
    });
  });
  it('should sort files/siblings by prop and direction', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [{
        name: 'archive'
      }, {
        name: 'greatest hits'
      }, {
        name: 'b-sides'
      }],
      siblings: [{
        name: 'Januaray'
      }, {
        name: 'November'
      }]
    });
    const el = jest.spyOn(_react.default, 'useState');
    el.mockReturnValue([{
      property: 'name',
      sort: 'desc'
    }]);
    global.shallow( /*#__PURE__*/_react.default.createElement(_DirectorySort.default, null, ({
      files,
      siblings
    }) => {
      expect(files).toEqual([{
        name: 'greatest hits'
      }, {
        name: 'b-sides'
      }, {
        name: 'archive'
      }]);
      expect(siblings).toEqual([{
        name: 'November'
      }, {
        name: 'Januaray'
      }]);
      return null;
    }));
    expect(el).toHaveBeenCalledWith({
      property: 'name',
      sort: 'asc'
    });
  });
  it('should mark menu items when active', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [],
      siblings: []
    });
    const items = getMenuItems();

    // 3 props and 2 directions
    expect(items).toHaveLength(5);
    const updatedAt = items.first();
    const name = items.at(1);

    // confirms we're looking at the right ones
    expect(updatedAt.text()).toMatch('updatedAt');
    expect(name.text()).toMatch('name');
    (0, _enzymeUtils.doesNotExist)(updatedAt.find(_Check.default));
    (0, _enzymeUtils.exists)(name.find(_Check.default));
  });
  it('should update state partially on menu click', () => {
    _useDirectoryFolders.default.mockReturnValue({
      files: [],
      siblings: []
    });
    const setState = jest.fn().mockImplementation(c => expect(c({
      property: 'size',
      sort: 'asc'
    })).toMatchObject({
      property: 'size',
      sort: 'desc'
    }));
    jest.spyOn(_react.default, 'useState').mockReturnValue([{}, setState]);
    const spy = jest.spyOn(_q3UiHelpers.browser, 'proxyLocalStorageApi').mockReturnValue(undefined);
    getMenuItems().last().props().onClick();
    expect(setState).toHaveBeenCalled();
    expect(spy).toHaveBeenCalledWith('setItem', 'q3-filemanager-sort', 'desc');
  });
});
